@@ -1,6 +1,6 @@
 import os
 import logging
-from typing import Tuple
+from typing import Tuple, Dict
 
 logger = logging.getLogger(__name__)
 
@@ -40,3 +40,6 @@ def walk_extension_files(path: str, extension: str | Tuple[str]):
 
 def walk_images(path: str):
     return walk_extension_files(path, suffix=IMG_EXTENSIONS)
+
+
+
