@@ -10,6 +10,10 @@ from .latex import (
     DataPoint,
     ListDataPoint,
     TableDataPoint,
+    ListMultiCellInfo,
+    ListMultiRowInfo,
+    TableRow,
     register_highlight_format,
     list_all_highlight_format,
 )
+from .font_color import get_colored_str
