@@ -2,6 +2,9 @@ from .table import (
     DataPoint,
     ListDataPoint,
     TableDataPoint,
+    ListMultiCellInfo,
+    ListMultiRowInfo,
+    TableRow,
     register_highlight_format,
     list_all_highlight_format,
 )
